@@ -84,13 +84,15 @@ const char* SacParser::kValueName[] = {
 
 // --------------------------------------------------------------------
 
-SacParser::SacParser(std::istream& is)
+SacParser::SacParser(std::istream& is, bool init)
 	: mData(is)
 {
 	mValidate = true;
 	mLineNr = 1;
 	mBol = true;
-	mLookahead = getNextToken();
+
+	if (init)
+		mLookahead = getNextToken();
 }
 
 void SacParser::error(const std::string& msg)
@@ -521,6 +523,203 @@ SacParser::CIFToken SacParser::getNextToken()
 	return result;
 }
 
+DatablockIndex SacParser::indexDatablocks()
+{
+	DatablockIndex index;
+
+	// first locate the start, as fast as we can
+	auto &sb = *mData.rdbuf();
+
+	enum {
+		start, comment, string, string_quote, qstring, data, data_name
+	} state = start;
+
+	int quote = 0;
+	bool bol = true;
+	const char dblk[] = "data_";
+	std::string::size_type si = 0;
+	std::string datablock;
+
+	for (auto ch = sb.sbumpc(); ch != std::streambuf::traits_type::eof(); ch = sb.sbumpc())
+	{
+		switch (state)
+		{
+			case start:
+				switch (ch)
+				{
+					case '#':	state = comment;	break;
+					case 'd':
+					case 'D':
+						state = data;
+						si = 1;
+						break;
+					case '\'':
+					case '"':
+						state = string;
+						quote = ch;
+						break;
+					case ';':
+						if (bol)
+							state = qstring;
+						break;
+				}
+				break;
+			
+			case comment:
+				if (ch == '\n')
+					state = start;
+				break;
+
+			case string:
+				if (ch == quote)
+					state = string_quote;
+				break;
+			
+			case string_quote:
+				if (std::isspace(ch))
+					state = start;
+				else
+					state = string;
+				break;
+			
+			case qstring:
+				if (ch == ';' and bol)
+					state = start;
+				break;
+			
+			case data:
+				if (dblk[si] == 0 and isNonBlank(ch))
+				{
+					datablock = { static_cast<char>(ch) };
+					state = data_name;
+				}
+				else if (dblk[si++] != ch)
+					state = start;
+				break;
+			
+			case data_name:
+				if (isNonBlank(ch))
+					datablock.insert(datablock.end(), char(ch));
+				else if (isspace(ch))
+				{
+					if (not datablock.empty())
+						index[datablock] = mData.tellg();
+					
+					state = start;
+				}
+				else
+					state = start;
+				break;
+		}
+
+		bol = (ch == '\n');
+	}
+
+	return index;
+}
+
+bool SacParser::parseSingleDatablock(const std::string& datablock)
+{
+	// first locate the start, as fast as we can
+	auto &sb = *mData.rdbuf();
+
+	enum {
+		start, comment, string, string_quote, qstring, data
+	} state = start;
+
+	int quote = 0;
+	bool bol = true;
+	std::string dblk = "data_" + datablock;
+	std::string::size_type si = 0;
+	bool found = false;
+
+	for (auto ch = sb.sbumpc(); not found and ch != std::streambuf::traits_type::eof(); ch = sb.sbumpc())
+	{
+		switch (state)
+		{
+			case start:
+				switch (ch)
+				{
+					case '#':	state = comment;	break;
+					case 'd':
+					case 'D':
+						state = data;
+						si = 1;
+						break;
+					case '\'':
+					case '"':
+						state = string;
+						quote = ch;
+						break;
+					case ';':
+						if (bol)
+							state = qstring;
+						break;
+				}
+				break;
+			
+			case comment:
+				if (ch == '\n')
+					state = start;
+				break;
+
+			case string:
+				if (ch == quote)
+					state = string_quote;
+				break;
+			
+			case string_quote:
+				if (std::isspace(ch))
+					state = start;
+				else
+					state = string;
+				break;
+			
+			case qstring:
+				if (ch == ';' and bol)
+					state = start;
+				break;
+			
+			case data:
+				if (isspace(ch) and dblk[si] == 0)
+					found = true;
+				else if (dblk[si++] != ch)
+					state = start;
+				break;
+		}
+
+		bol = (ch == '\n');
+	}
+
+	if (found)
+	{
+		produceDatablock(datablock);
+		mLookahead = getNextToken();
+		parseDataBlock();
+	}
+
+	return found;
+}
+
+bool SacParser::parseSingleDatablock(const std::string& datablock, const DatablockIndex &index)
+{
+	bool result = false;
+
+	auto i = index.find(datablock);
+	if (i != index.end())
+	{
+		mData.seekg(i->second);
+
+		produceDatablock(datablock);
+		mLookahead = getNextToken();
+		parseDataBlock();
+
+		result = true;
+	}
+
+	return result;
+}
+
 void SacParser::parseFile()
 {
 	while (mLookahead != eCIFTokenEOF)
@@ -642,8 +841,8 @@ void SacParser::parseSaveFrame()
 
 // --------------------------------------------------------------------
 
-Parser::Parser(std::istream& is, File& f)
-	: SacParser(is), mFile(f), mDataBlock(nullptr)
+Parser::Parser(std::istream& is, File& f, bool init)
+	: SacParser(is, init), mFile(f), mDataBlock(nullptr)
 {
 }
 
@@ -687,9 +886,9 @@ void Parser::produceItem(const std::string& category, const std::string& item, c
 struct DictParserDataImpl
 {
 	// temporary values for constructing dictionaries
-	std::vector<ValidateCategory>			mCategoryValidators;
+	std::vector<ValidateCategory>					mCategoryValidators;
 	std::map<std::string,std::vector<ValidateItem>>	mItemValidators;
-	std::set<std::tuple<std::string,std::string>>			mLinkedItems;
+	std::set<std::tuple<std::string,std::string>>	mLinkedItems;
 };
 
 DictParser::DictParser(Validator& validator, std::istream& is)
@@ -1036,7 +1235,7 @@ void DictParser::loadDictionary()
 			}
 		}
 	}
-	catch (const std::exception& ex)
+	catch (const std::exception&)
 	{
 		std::cerr << "Error parsing dictionary" << std::endl;
 		throw;
@@ -1099,12 +1298,12 @@ bool DictParser::collectItemTypes()
 		try
 		{
 			ValidateType v = {
-				code, mapToPrimitiveType(primitiveCode), std::regex(construct, std::regex::extended | std::regex::optimize)
+				code, mapToPrimitiveType(primitiveCode), boost::regex(construct, boost::regex::extended | boost::regex::optimize)
 			};
 			
 			mValidator.addTypeValidator(std::move(v));
 		}
-		catch (const std::exception& ex)
+		catch (const std::exception&)
 		{
 			throw_with_nested(CifParserError(t.lineNr(), "error in regular expression"));
 		}
